Welcome to ooi's documentation!
========================================================

ooi is an implementation the Open Grid Forum's `Open Cloud Computing Interface
(OCCI)`_ for `OpenStack`_.

.. _Open Cloud Computing Interface (OCCI): http://www.occi-wg.org
.. _OpenStack: http://www.openstack.org


User documentation
------------------
.. toctree::
    :maxdepth: 2

    user/index

Developer documentation
-----------------------
.. toctree::
    :maxdepth: 2

    developer

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
